@@ -2,8 +2,8 @@ package Glib::Install::Files;
 
 $self = {
           'deps' => [],
-          'inc' => ' -I. -I/usr/pkg/include/glib/glib-2.0 -I/usr/pkg/lib/glib-2.0/include -I/usr/pkg/include -pthread -I/usr/pkg/include/glib/glib-2.0 -I/usr/pkg/lib/glib-2.0/include -I/usr/pkg/include',
-          'libs' => '-L/usr/pkg/lib -Wl,-R/usr/pkg/lib -lgobject-2.0 -Wl,-R/usr/pkg/lib -lglib-2.0 -lintl -L/usr/pkg/lib -Wl,-R/usr/pkg/lib -lgthread-2.0 -pthread -Wl,-R/usr/pkg/lib -lglib-2.0 -lintl',
+          'inc' => ' -I. -I/usr/pkg/include/glib/glib-2.0 -I/usr/pkg/lib/glib-2.0/include -I/usr/pkg/include   -pthread -I/usr/pkg/include/glib/glib-2.0 -I/usr/pkg/lib/glib-2.0/include -I/usr/pkg/include  ',
+          'libs' => '-L/usr/pkg/lib -lgobject-2.0 -Wl,-R/usr/pkg/lib -lglib-2.0 -lintl   -L/usr/pkg/lib -lgthread-2.0  -pthread -Wl,-R/usr/pkg/lib -lglib-2.0 -lintl  ',
           'typemaps' => [
                           'typemap'
                         ]
